In situ liquid-cell electron microscopy of silver–palladium galvanic replacement reactions on silver nanoparticles | Nature Communications
Author: E. Sutter
Description: Galvanic replacement reactions provide an elegant way of transforming solid nanoparticles into complex hollow morphologies. Conventionally, galvanic replacement is studied by stopping the reaction at different stages and characterizing the products ex situ. In situ observations by liquid-cell electron microscopy can provide insight into mechanisms, rates and possible modifications of galvanic replacement reactions in the native solution environment. Here we use liquid-cell electron microscopy to investigate galvanic replacement reactions between silver nanoparticle templates and aqueous palladium salt solutions. Our in situ observations follow the transformation of the silver nanoparticles into hollow silver–palladium nanostructures. While the silver–palladium nanocages have morphologies similar to those obtained in ex situ control experiments the reaction rates are much higher, indicating that the electron beam strongly affects the galvanic-type process in the liquid-cell. By using sc [cell cut: 1426 characters, first 1000 kept]
Keywords: Electrochemistry
Date: 2014-09-11

Skip to main content

Advertisement

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

- Published: 11 September 2014

# In situ liquid-cell electron microscopy of silver–palladium galvanic replacement reactions on silver nanoparticles

- E. Sutter
  1,
- K. Jungjohann1,
- S. Bliznakov2,
- A. Courty3,
- E. Maisonhaute4,
- S. Tenney1 &
- P. Sutter1

Nature Communications volume 5, Article number: 4946 (2014) Cite this article

- 1833 Accesses

- 117 Citations

- 10 Altmetric

- Metrics details

### Subjects

- Electrochemistry
- Microscopy
- Nanoparticles

## Abstract

Galvanic replacement reactions provide an elegant way of transforming solid nanoparticles into complex hollow morphologies. Conventionally, galvanic replacement is studied by stopping the reaction at different stages and characterizing the products ex situ. In situ observations by liquid-cell electron microscopy can provide insight into mechanisms, rates and possible modifications of galvanic replacement reactions in the native solution environment. Here we use liquid-cell electron microscopy to investigate galvanic replacement reactions between silver nanoparticle templates and aqueous palladium salt solutions. Our in situ observations follow the transformation of the silver nanoparticles into hollow silver–palladium nanostructures. While the silver–palladium nanocages have morphologies similar to those obtained in ex situ control experiments the reaction rates are much higher, indicating that the electron beam strongly affects the galvanic-type process in the liquid-cell. By using scavengers added to the aqueous solution we identify the role of radicals generated via radiolysis by high-energy electrons in modifying galvanic reactions.

Download PDF

## Introduction

Solution synthesis has demonstrated unprecedented control over the size, shape and morphology of nanoparticles of different metals. Furthermore, initially homogeneous metal nanoparticles with well-defined shapes can serve as a starting material in galvanic replacement reactions, in which they are used as sacrificial templates to produce hollow and porous nanostructures with complex morphologies, such as nanoboxes or nanocages1,2,3,4,5,6,7,8,9. Such hollow and porous structures have drawn interest as they can shift plasmon resonances compared with those of solid nanoparticles5,10, may provide nanoscale containers for biomedical applications such as diagnostics and drug delivery11, are of use as contrast enhancement agents in optical imaging such as optical coherence12, photoacoustic tomography13,14, and are found to be highly active in catalysis15,16,17,18,19,20 and electrocatalysis21,22. The galvanic replacement reaction is critical in the advanced two-step synthesis of fuel cell electrocatalysts with reduced precious metal loadings, limited to a thin surface layer or even a monolayer on top of less expensive metal nanoparticles23,24,25,26,27,28,29,30,31,32,33. The electrocatalysts obtained either via the transmetalation of an underpotentially deposited23,26,28 or electrodeposited27,29,30,31,32,33 monolayer or thin layer of a less precious metal by a precious metal upon immersion into a complex solution of Pt, Pd or Au ions23,26,27,28,29,30,31,32,33, or by partial galvanic replacement24,25 exhibit enhanced activity compared to the most active Pt catalysts23,24,25,26,27,28,29,30,31,32,33.

Galvanic replacement reactions using Ag nanoparticles as sacrificial templates have recently been demonstrated as a simple and elegant way of producing hollow and porous nanostructures of noble metals (Au, Pd and Pt)3,6,8. When a suspension of Ag nanoparticles is titrated with aqueous solutions of different metal precursors, such as HAuCl4 or PdCl2, galvanic replacement between the two species occurs spontaneously and leads to the formation of hollow nanoparticles whose morphology depends on that of the starting templates. In the reaction, [AuCl4]− or [PdCl4]2− oxidizes Ag to AgCl, which causes the hollowing-out of the sacrificial Ag templates.

The morphological and structural changes of nanoparticles due to galvanic replacement are typically investigated ex situ by transmission electron microscopy (TEM) on samples taken at different stages of the reaction34. So far, the only in situ observation of the process on the nanoscale has been a transmission X-ray microscopy study of galvanic replacement in large (>100 nm diameter) Ag nanowires with 10–15 nm spatial resolution35. In situ closed-cell microscopy, capable of imaging processes in liquid environments enclosed between thin SiN membranes in real time by TEM or scanning TEM (STEM), has the potential to go beyond this ‘quench-and-look’ approach and image reactions while they occur in solution. Liquid-cell microscopy has made considerable progress recently. It provides a platform for the quantitative analysis of nanoparticle dynamics in liquids, of solution growth without36,37 or with38,39 a template, and of electrochemical deposition40,41,42, and has been shown to be capable of sub-nanometer resolution43,44. Nanoparticle growth within the liquid cell is generally initiated through reduction of a precursor by the imaging electron beam36,37,39,45,46,47, though decoupling the growth from electron beam effects has been explored37. Nanoparticle dynamics observed within the liquid cell generally deviate from Brownian motion due to electron beam effects and interactions with the enclosing SiN membranes, facilitating the continuous imaging of individual nanostructures in solution48,49.

While in situ observations can provide unique insight into processes in liquid environments, the imaging electron beam invariably affects these processes, for example, by creating radicals such as hydrated electrons that can reduce metal salts and thus drive or accelerate redox chemistry. To properly interpret liquid-cell experiments and to be able to use electron irradiation judiciously to control in situ solution chemistry, it is important to understand the effects caused by the electron beam. Here we use liquid-cell TEM and STEM to investigate galvanic replacement reactions and their modification by radicals generated via radiolysis by a high-energy electron beam. Specifically, we consider reactions in Pd-salt solutions, which transform Ag nanoparticle templates into complex Ag–Pd nanostructures. Real-time observations allow us to follow the evolution of Ag templates into porous and solid nanocages, to directly identify the role of the electron beam in this process and to gain insight into novel pathways for modifying galvanic replacement processes. To study galvanic-type reactions and the effects of high-energy electron irradiation, we perform complementary experiments comprising real-time in situ liquid-cell TEM and STEM, as well as control experiments in which reactions are set to proceed on the bench without electron irradiation. In both cases, ex situ electron microscopy and complementary analytical methods are used to evaluate the reaction products with high spatial resolution and chemical specificity.

## Results

### Galvanic replacement without electron irradiation

Before discussing the results of in situ (S)TEM experiments, we establish the behaviour observed via the conventional ‘quench-and-look’ approach, in which the reaction—proceeding in absence of an electron beam (that is, on the bench)—is stopped at defined intervals and the resulting morphologies are imaged by TEM and STEM. These data provide a benchmark for determining modifications induced by the electron beam during in situ observations of the reaction. We focus on a replacement reaction involving the oxidation of Ag nanoparticles and reduction of Pd ions in an aqueous PdCl2 solution generally used for electrochemical Pd deposition on different substrates39. The prevailing Pd complexes in the aqueous solution are metal–chloro complexes, that is, tetrachloropalladate ions (PdCl4)2−, which are reduced by the capture of two electrons: (PdCl4)2−+2e−⇌Pd+4Cl−. Figures 1a,b and 2a,b show TEM and high-angle annular dark-field (HAADF) STEM images of the starting Ag nanoparticles, respectively. The majority of the Ag particles are multiple twinned (Figs 1b and 2b), often with irregular shapes comprising several corners and asperities. The majority of the particles have diameters between 29 and 33 nm; the mean diameter is 31.2±0.25 nm (Fig. 2c).

Figure 1: Galvanic replacement of Ag particles in Pd-salt solution without electron irradiation.

(a) TEM image of the initial Ag nanoparticles; scale bar, 50 nm. (b) HR-TEM images of three representative Ag nanoparticles; scale bar, 20 nm. (c) TEM image of the Ag–Pd hollow nanostructures formed after 4 h of immersion of the Ag nanoparticles in 50 μM PdCl2 aqueous solution. For ease of comparison, the image scale is identical to that in a; scale bar, 50 nm. (d,e) EDS spectra of a Ag nanoparticle and a Ag–Pd hollow-shell nanostructure, respectively.

Full size image
Figure 2: Morphology and size distribution changes of Ag nanoparticles during galvanic replacement in Pd-salt solution without electron irradiation.

HAADF–STEM images of (a,b)—the initial Ag nanoparticles and (d,e) the Ag–Pd hollow nanostructures formed after 4 h of immersion of the Ag nanoparticles in 50 μM PdCl2 aqueous solution. To facilitate comparison, the image scales are identical in a,d, (scale bar, 100 nm) and in b,e (scale bar, 20 nm). Distribution of nanoparticle sizes of (c)—the initial Ag nanoparticles and (f)—the Ag–Pd nanostructures.

Full size image

The reaction of Ag particles in a 50 μM PdCl2 precursor solution (see Methods for details) was carried out at room temperature to ensure conditions identical to those in the microscope. Imaging of the nanoparticles at different stages, that is, by quenching the reaction after 1, 2 and 4 h after immersion in the Pd solution showed the development of characteristic morphological and chemical changes. The nanoparticles hollowed out gradually, that is, transformed into porous crystalline shells (Figs 1c and 2d,e). The hollowing of the nanoparticles was accompanied by a distinct increase in size. The particle size distribution shifted significantly towards larger sizes, and after 4 h, the majority of the nanoparticles have diameters between 36 and 44 nm; the mean diameter is 41.2±2.2 nm (Fig. 2f). Energy-dispersive X-ray spectroscopy (EDS) analysis (Fig. 1e) shows that the shells contain both Ag and Pd, with high Ag content (~65–70 at. % Ag). We further attempted to determine the elements exposed in the outermost atomic layer by low-energy ion scattering spectroscopy (ISS). These measurements were not conclusive due to the similar mass of Ag and Pd atoms (Supplementary Fig. 1). Instead, X-ray photoelectron spectroscopy (XPS) of both Ag and Pd core levels, and especially of Pd Auger transitions, provided clear evidence of the composition and chemical state of Pd and Ag in the hollow nanoshells. Both investigations were performed on nanoparticle ensembles identical to the ones shown in Figs 1c and 2d, dispersed on Ge substrates.

XPS on the Ag–Pd nanoshells confirms the presence of Ag (Fig. 3a) and Pd (Fig. 3c). The Ag 3d5/2 peak (~368.15 eV) is shifted to lower binding energy compared with a Ag single crystal reference (~368.3 eV, Fig. 3b), in agreement with a similar shift observed upon alloy formation in small Ag–Pd clusters and Ag and Pd supported clusters50. The Pd 3d5/2 peak (~335.1 eV) is not significantly shifted from the reported value for pure Pd single crystals. However, a significant shift would not be expected since upon alloying with up to 50% Ag, the Pd 3d5/2 binding energy shifts by at most 0.1 eV, that is, it is insensitive to alloying with Ag in this concentration range50. The Pd M4,5 VV Auger spectrum is more suitable to detect alloying with Ag, as it has characteristic fine structure that changes with alloying, that is, can be used to quantify the composition of Ag–Pd alloys50,51,52. The line shape of the Pd M4,5 VV Auger spectrum measured on our Ag–Pd nanoshells (Fig. 3d) indicates that Pd is in a Ag0.7Pd0.3 alloy, that is, the measurement confirms the formation of a Ag–Pd alloy upon formation of the hollow nanoshells.

Figure 3: X-ray photoelectron spectroscopy of the Ag–Pd hollow shell nanostructures.

(a) X-ray photoelectron spectra of Ag 3d core levels of the composite Ag–Pd nanoshells compared with (b) the Ag 3d spectra of a silver single crystal standard. (c) X-ray photoelectron spectrum of Pd 3d core levels of the nanoshells. (d) Pd Auger electron spectrum of the composite Ag–Pd nanoshells formed by galvanic replacement.

Full size image

Longer reaction times did not lead to significant further changes in morphology. The Pd content stayed at a maximum of ~30–35 at. %, similar to earlier results on galvanic replacement reactions between these two metals3. The Pd content could not be increased further, neither by increasing the Pd-salt concentration in the solution (up to 1 mM) nor the reaction time. Previous work for the Pd–Ag system showed a termination of galvanic replacement once nanoboxes composed of a Pd–Ag alloy containing~30–35 at. % Pd was produced, suggesting that the formation of a homogeneous alloy (or possibly coverage by a complete Pd monolayer) eliminated the electrochemical driving force for the further oxidation of Ag53. This is unlike Au–Ag1,3, where a much larger difference in the standard electrochemical potentials drives the galvanic replacement beyond the nanobox stage and a complete de-alloying can be achieved3,34.

### Real-time TEM imaging of galvanic-type reactions

Ag nanoparticles were introduced in PdCl2 aqueous solution identical to those used in our benchtop reference experiments, loaded into the liquid cell and subjected to in situ TEM and STEM observations of the galvanic replacement process.

Figure 4 shows representative in situ TEM observations of Ag nanoparticles in PdCl2 aqueous solution (see also Supplementary Movie 1). Figure 4a is an initial TEM image of a group of Ag nanoparticles. While Ag particles in aqueous solution without PdCl2 are generally imaged with homogenous contrast, the particles in the PdCl2 solution are slightly hollow already in the initial image, due to the fact that a galvanic replacement reaction starts at the moment of immersing the particles in the solution, about 10–15 min before the first images are obtained in the microscope. Following the further evolution of the particle morphology over time, we find that the particles lose contrast very quickly as the Ag in their interior is depleted and holes develop in their surface. Figure 4b shows in situ liquid TEM images of the same group of particles after 52 s elapsed observation time. The particles now appear completely hollowed out, that is, have transformed into empty shells. Z-contrast images (Figs 4c and 5) taken after quenching the reaction and opening the liquid cell confirm that the particles are empty porous shells with homogenous composition. The cages are Ag rich and contain 10–20 at. % Pd, as shown by EDS (Supplementary Fig. 2). The highest Pd content we detected in a survey of several Ag–Pd nanocages was ~20 at. %. Finally, Z-contrast images (for example, Fig. 5b) show that the porous nanocages are invariably surrounded by numerous small Ag-containing nanoparticles.

Figure 4: Evolution of Ag particles in 10 μM aqueous PdCl 2 solution during in situ TEM imaging.

(a) Initial TEM image of an ensemble of Ag nanoparticles in the liquid cell (scale bar, 100 nm) and higher magnification images of two of the particles (right of panel, scale bar, 20 nm). (b) The same group of nanoparticles (scale bar, 100 nm), and the same two individual particles (right of panel, scale bar 20 nm) after 52 s. Electron dose rate: 15.6 e−Å−2s−1. Total dose per image: 5.2 e−Å−2. Cumulative electron dose between a and b: 811 e−Å−2. (c) Ex situ high-resolution Z-contrast image of three Ag–Pd nanoparticles formed in the process (scale bar. 20 nm).

Full size image
Figure 5: Ex situ characterization of Ag–Pd nanocages formed during in situ TEM observations.

(a–c) High-resolution HAADF–STEM images of representative porous Ag–Pd nanocages; scale bar, 20 nm. Note the arrays of small nanoparticles in the vicinity of the larger nanocages (outlined by a dashed oval). (d) EDS spectrum from a Ag–Pd nanocage.

Full size image

Ex situ high-resolution bright-field STEM and HAADF–STEM (Fig. 6a,b, respectively) of the larger Ag–Pd nanocage in Fig. 5b, shows that the shells are crystalline and that holes have formed in the crystalline matrix. Tilt series (Supplementary Movie 2) demonstrate that the holes are distributed over the entire surface, that is, the shells are porous single crystalline nanocages.

Figure 6: High-resolution imaging of Ag–Pd nanocages.

(a,b) High-resolution BF-STEM and HAADF–STEM images of a representative hollow cage Ag–Pd nanoparticle (inset: FFT of the entire nanocage, Fig. 5b). h, hole in the nanoparticle surface. Scale bar, 5 nm. (c) Higher magnification of the square area marked in a. Scale bar, 5 nm.

Full size image

The comparison of the in situ observations of Ag nanoparticles in aqueous PdCl2 solution with the results of the galvanic displacement reaction in the same solution on the bench shows several close similarities. In both cases, there is a transformation from nanoparticles to nanocages, accompanied by an overall size increase to diameters of ~40 nm similar to the one observed in the galvanic experiments on the bench. Occasionally, larger particles of ~65 nm are also observed, likely generated by coalescence of closely spaced smaller Ag nanoparticles (Fig. 4a). Hence, we conclude that the reaction observed in situ in the liquid cell is also a redox process. However, the hollowing-out of the Ag particles and conversion into porous Ag–Pd nanocages occurs much faster than in the benchtop galvanic replacement reaction. This difference in the reaction rates suggests that the electron beam strongly affects the galvanic-type process in the liquid cell. In situ observations show a significant loss of Ag in the particle interior during the initial 8 s of observation, that is, within this brief interval the Ag particles undergo changes that require ~2 h on the bench. The fact that the fast replacement reaction is localized within the field-of-view (FOV) in TEM further supports our conclusion that the electron beam plays an important role in driving the reaction in the liquid cell, that is, represents an invasive probe that alters the reaction rate, and possibly the reaction pathway as well.

### Real-time STEM imaging of galvanic-type reactions

The way in which electrons are delivered in the two imaging modes, TEM and STEM, is very different46. In TEM, the FOV is exposed uniformly and at constant rate to a collimated electron beam, whereas in STEM a tightly focused beam is scanned across the FOV and delivers high electron doses during brief time intervals into sub-nanometer spots within the liquid cell. To gain additional information on the role of the electron beam in galvanic processes in aqueous solution, we performed in situ experiments in STEM mode. Figure 7 shows a series of dark-field STEM images tracking the evolution of a characteristic Ag nanoparticle in the aqueous PdCl2 solution (10 μM PdCl2). The Ag particles are very mobile (for example, Supplementary Movies 3 and 4) and with each time-step the number of the nanoparticles in the FOV changes due to sudden displacements (‘jumps’)39,54. In Figs 7a–l and 8a–f, we track individual particles that could reliably be followed as they remain in the FOV during the entire sequence.

Figure 7: Evolution of Ag particles in 10 μM aqueous PdCl 2 solution during in situ STEM imaging.

(a–l) Sequence of HAADF–STEM images following the evolution of a Ag particle in 10 μM aqueous PdCl2 solution. Electron dose rate: 48 e−Å−2s−1; frame time: 2.1 s. Electron dose per image: 102 e−Å−2. Scale bar, 100 nm.

Full size image
Figure 8: Evolution of a representative Ag particle in 50 μM aqueous PdCl 2 solution.

(a–f): Time-lapse series of dark-field STEM images following one Ag particle over 50.4 s in 50 μM aqueous PdCl2 solution. Electron dose rate: 6.26 e−Å−2s−1, frame time: 8.4 s. Electron dose per image: 52 e−Å−2. Scale bar, 50 nm.

Full size image

From one frame to the next (Δt=2.1 s), the Ag particle changes gradually in such a way that it transforms into a hollow nanostructure within 20–30 s. The particle increases in size by the deposition of Pd and formation of a Ag–Pd alloy during hollowing-out of the Ag from the particle core. Large holes develop in parallel with a pronounced thickening of corners and the Ag particle transforms into a porous hollow cage, similar to the behaviour of the Ag nanoparticles we observed during TEM imaging. The time scale of the nanoparticle-to-nanocage transformation is similar (order of seconds) independent of the imaging mode, TEM or STEM.

There is a substantial difference in the morphology of the nanocages depending on the mode of observation. In contrast to the behaviour during TEM imaging—a hollowing-out similar to the replacement reaction on the bench, and complete absence of homogeneous nucleation in the solution—the cages formed in STEM grow thicker over time. Furthermore, significant homogeneous nucleation and growth in the solution surrounding the cages occurs in the whole range of electron dose rates and in the Pd precursor concentrations surveyed here (10–50 μM PdCl2; 3–50 e−Å−2s−1), in agreement with our earlier observations39.

The morphology of the Ag–Pd shell nanostructures generated during in situ STEM imaging was investigated ex situ via high-resolution Z-contrast imaging (Supplementary Fig. 2), which clearly shows the porous morphology of the nanocages. The concentration of Pd (up to 44 at. %) is higher than that obtained on the bench or under electron irradiation in TEM mode. The morphology of the shells can be controlled by the molarity of the Pd precursor metal complexes in the solution. In 50 μM PdCl2, for instance, (Fig. 8 and Supplementary Figs 3 and 4, Supplementary Movies 3 and 4) large holes never develop, and a solid shell appears to thicken in consecutive image frames (8.4 s per frame). EDS maps show that Pd and Ag are uniformly distributed over the shell, with Pd content varying between 0 and 44 at. %. The overview image in Supplementary Fig. 3a shows Ag particles with large variations in the degree of transformation into Ag–Pd shells, a consequence of different times spent in the FOV and exposed to the electron beam, due to the high mobility of the Ag nanoparticles. The thickening of the shell is more pronounced for particles near the centre of the FOV where the beam resides longer, consistent with previous observations on the growth of Pd–Au core-shell nanoparticles39. Particles outside the FOV (that is, not irradiated by the beam) show much slower morphological changes, consistent with the rates of galvanic replacement without electron irradiation.

## Discussion

The comparison of our ex situ experiments on the bench and of real-time electron microscopy observations in liquid cells allows us to obtain unprecedented insight into the effects of high-energy electrons on galvanic replacement reactions. In the galvanic reaction on the bench, the Ag nanoparticles undergo a slow hollowing-out, whose rate is controlled by the electrochemical potentials of the involved species. In brief, the sacrificial Ag template is oxidized by the (PdCl4)2− to Ag+, which rapidly reacts with Cl− ions to form AgCl. The electrons (eG−) generated in the oxidation half-reaction reduce (PdCl4)2− to Pd0 at the surface of the Ag particles. The standard reduction potential of the (PdCl4)2−/Pd pair (0.62 V versus standard hydrogen electrode (SHE)) is higher than that of the AgCl/Ag pair (0.22 V versus SHE)3, that is, the overall redox reaction is expected to proceed spontaneously (equation (1)):

Pd and Ag have the same fcc structure, similar lattice constants and can interdiffuse at room temperature. Hence, Pd atoms incorporated in the Ag surface form small Pd–Ag alloy patches. The Ag oxidation proceeds via the formation of holes, through which Ag from the particle interior can be released into the solution over the period of a couple of hours. According to theoretical calculations and earlier experiments, the overall driving force for the galvanic displacement vanishes and the galvanic reaction stops once the hollow shell becomes a homogeneous Ag–Pd alloy3,8,53.

High-energy electron beams affect aqueous solutions through the radiolysis of water, a process in which a number of transient species are generated. The reaction cascades induced by radiolysis can be very complex. The major species generated include hydrated electrons (eaq−)—strong reducing agents that can react with metal ions or charged complexes in solution at a diffusion-controlled rate to form zero-valent metal atoms or atom clusters55,56,57—and hydroxyl radicals (OH·)56, which can act as potent oxidizers. The reduction by eaq− is well-established for Pd complexes, (PdCl4)2−+2eaq−⇌Pd0+4Cl−, and was used in real-time electron microscopy of the growth of Pd nanoparticles and Au–Pd core-shell nanostructures in aqueous solution39. The presence of beam-induced species, such as eaq− and OH· can cause major deviations from the conventional galvanic replacement reaction (equation (1)). The OH· radicals can react with one another and form H2O2, or with eaq− to form OH−, or with alcohols. At different experimental parameters, it is thus possible to achieve net oxidizing or reducing conditions, which has been exploited for a long time for preparation of nanoparticles by gamma radiolysis58,59. In contrast to the galvanic process on the bench, where the reduction of (PdCl4)2− requires eG− generated via the oxidation of Ag, the electron beam creates a second population of reducing agents, that is, eaq− generated by radiolysis. In addition to the long-lived eaq− (lifetime t~1 μs)39,60, radiolysis by the electron beam liberates short-lived (t~ns), highly reactive OH· radicals61,62,63. Our previous observations of the Pd nanoparticle growth in liquid-cell STEM show that OH· radicals do not play a significant role in liquid-cell microscopy of Pd growth, likely due to the fact that overall reducing conditions are achieved as the hydrated electrons diffuse much further and have a longer lifetime39. However, the real-time observations shown here, along with control experiments discussed below, indicate that OH· radicals can be important in galvanic-type processes. Indeed, the presence of abundant OH· can explain the vastly accelerated oxidation of Ag in our liquid-cell experiments compared with the reaction on the bench. OH· enables a second redox pathway (equation (2)),

which essentially decouples the oxidation of Ag from the reduction of (PdCl4)2− (that is, generation of eG−).

It is well-known that alcohols react effectively with OH·, primarily via hydrogen abstraction producing a radical and H2O56. OH· is quenched by isopropanol according to: . To support our conclusion that OH· accelerates Ag oxidation in liquid-cell microscopy, we have performed control experiments in which isopropanol was added to the aqueous PdCl2 solution to scavenge OH· radicals. Figure 9 shows selected images from time-lapse series of liquid-cell STEM images of the evolution of a Ag nanoparticle in 10 μM aqueous PdCl2, to which 0.1 mM of isopropanol were added. The hollowing-out, previously observed on the bench and in liquid-cell (S)TEM, is now completely suppressed. Instead, the particle progressively increases in size, apparently by deposition of Pd on the Ag nanoparticle core, similar to the formation of Au–Pd core-shell nanoparticles39. In addition, homogeneous nucleation of Pd clusters takes place in the solution. We conclude that eliminating OH· radicals from the solution without affecting the population of eaq− had the effect of dramatically lowering the Ag oxidation rate while the rate of (PdCl4)2− reduction remained high, as the CH3C·OHCH3 radical is a strong reducing system (E°((CH3)2CO/(CH3)2C·OH)=−1.8 V) also able to reduce (PdCl4)2−, reinforcing the effect of e−aq via

Figure 9: Evolution of a representative Ag particle in 10 μM aqueous PdCl 2 solution with added isopropanol.

(a–j) Sequence of HAADF–STEM images following the evolution of a Ag particle in 10 μM aqueous PdCl2 solution with added isopropanol. Electron dose rate: 48 e−Å−2s−1; frame time: 2.1 s. Electron dose per image: 102 e−Å−2. Scale bar, 100 nm.

Full size image

Overall, this shifted the reaction from a radical-modified galvanic replacement to the growth of Pd on the Ag cores, that is, formation of a Ag–Pd core-shell nanostructure.

A similar shift between these reactions can also explain the different morphologies obtained in liquid-cell TEM and STEM imaging, that is, porous versus solid nanocages. The characteristics observed in STEM—higher Pd concentration in the nanocages and homogeneous nucleation of Pd particles in the surrounding solution—suggest that the focused electron beam in STEM creates more abundant eaq−, and thus enables a second pathway of Pd0 formation (via equation (3)) that does not require eG− from the galvanic oxidation of Ag. In the extreme case of STEM imaging of Ag particles in concentrated aqueous PdCl2 solutions, significant Ag oxidation does not take place and the Ag particles are no longer hollowing-out. Instead, rapid Pd deposition causes the formation of a core-shell structure in which a solid Ag core is surrounded by a Pd shell.

In summary, by comparing the results of the in situ experiments to the ones obtained in control experiments without the influence of the electron beam we identify how solution phase redox chemistry is modified by radicals generated via radiolysis by a high-energy electron beam. We demonstrate the use of scavengers to both identify and control the radicals responsible for observed enhancements in the in situ reaction rates. In future studies such scavengers can be used judiciously to minimize electron beam effects and achieve reaction conditions close to those realized on the bench.

## Methods

### Materials

Solutions of palladium chloride (PdCl2, Fisher Scientific) were made by dissolving 88.65 mg of the salt in 300 μl HCl, which was then diluted with water to concentrations between 10 and 100 μM. For seeded growth, Ag nanoparticles (British Biocell International) with sizes of 20 and 30 nm and different concentrations (4.5 × 1011 particles per ml and 1.3 × 1011 particles per ml, respectively) were introduced in the solutions. Observations of Pd growth by liquid-cell electron microscopy were carried out at different PdCl2 concentrations above 5 μM PdCl2, the threshold for observable Pd growth under the observation conditions used here. Solutions with two different concentrations were used: 10 μM PdCl2 for STEM imaging, and 50 μM PdCl2 for both STEM and TEM imaging of the transformations of Ag nanoparticles in solution.

### In situ liquid-cell TEM and STEM experiments

The liquid experiments were carried out in a dedicated specimen holder (Hummingbird Scientific) using liquid cells consisting of two 30 nm thick SiN membrane windows with 50 × 50 μm2 window area. The spacing between the windows was controlled using 90 nm polystyrene beads or 100 and 200 nm SiO2 spacers. Bowing of the thin membrane allows a continuous range of liquid thicknesses to be established within the same cell39. (S)TEM imaging was performed in a FEI Titan 80–300 environmental Cs-corrected (in TEM mode) microscope operated at 300 kV. Low-loss electron energy loss spectra (EELS) were acquired on a Gatan Enfina spectrometer with an entrance aperture semiangle of 3.5 mrad. The local fluid thickness was calculated using low-loss EELS according to ref. 39 For the reaction followed in Supplementary Movie 1 and Fig. 4 the fluid thickness was ~330 nm and the electron dose per image was 5.2 e−Å−2. STEM imaging was performed with ~2 Å beam size and beam current between 0.18 and 0.22 nA, measured in vacuum before introduction of the liquid cell. Typical conditions for the acquisition of growth series were an electron dose rate between 5 and 50 e−Å−2s−1 and a fluid path length of 200–300 nm. Suitable serial acquisition imaging conditions were achieved by focusing at an appropriate distance from the area of interest, followed by blanking of the beam and translation to the area of interest. This procedure guaranteed that the area had not been exposed to electrons prior to scanning the first frame. A background intensity gradient visible in the images is likely related to the variation in fluid thickness.

### Ex situ characterization

High-resolution STEM images of the Au–Pd nanostructures were acquired ex situ using a Hitachi HD2700C 200 kV cold-field emission Cs-corrected STEM.

X-ray photoemission spectroscopy (XPS) and low-energy ISS was carried out in a UHV system with 1 × 10−9Torr base pressure, equipped with a SPECS Phoibos 100 spectrometer. The XPS measurements were carried out on Ag–Pd nanoshell ensembles deposited on Ge(111) substrates and reference Ag single crystal using Mg Ka radiation. The surface composition was probed by ISS measurements using 2 keV He-ions (SPECS IQE 12/38) ion source. The analyzer was normal to the sample surface while the X-ray and ion sources were positioned 45° off the surface normal. Both electrons and ions were detected with a 5-channel electron multiplier (Specs, MCD-5) mounted on the hemispherical analyzer.

## Additional information

How to cite this article: Sutter, E. et al. In situ liquid-cell electron microscopy of silver–palladium galvanic replacement reactions on silver nanoparticles. Nat. Commun. 5:4946 doi: 10.1038/ncomms5946 (2014).

## References

1. 1

   Skrabalak, S. E. et al. Gold nanocages: synthesis, properties, and applications. Acc. Chem. Res. 41, 1587–1595 (2008).

   CAS Article PubMed PubMed Central Google Scholar

2. 2

   Sun, Y. G., Mayers, B. T. & Xia, Y. N. Template-engaged replacement reaction: a one-step approach to the large-scale synthesis of metal nanostructures with hollow interiors. Nano Lett. 2, 481–485 (2002).

   CAS Article ADS Google Scholar

3. 3

   Cobley, C. M. & Xia, Y. N. Engineering the properties of metal nanostructures via galvanic replacement reactions. Mater. Sci. Eng. R 70, 44–62 (2010).

   Article Google Scholar

4. 4

   Clay, M. et al. Galvanic synthesis of bi-modal porous metal nanostructures using aluminum nanoparticle templates. Mater. Lett. 88, 143–147 (2012).

   CAS Article Google Scholar

5. 5

   Petri, M. V., Ando, R. A. & Camargo, P. H. C. Tailoring the structure, composition, optical properties and catalytic activity of Ag-Au nanoparticles by the galvanic replacement reaction. Chem. Phys. Lett. 531, 188–192 (2012).

   CAS Article ADS Google Scholar

6. 6

   Metraux, G. S., Cao, Y. C., Jin, R. C. & Mirkin, C. A. Triangular nanofrarnes made of gold and silver. Nano Lett. 3, 519–522 (2003).

   CAS Article ADS Google Scholar

7. 7

   Vasquez, Y., Sra, A. K. & Schaak, R. E. One-pot synthesis of hollow superparamagnetic CoPt nanospheres. J. Am. Chem. Soc. 127, 12504–12505 (2005).

   CAS Article PubMed Google Scholar

8. 8

   Xia, X. H., Wang, Y., Ruditskiy, A. & Xia, Y. N. 25th anniversary article: galvanic replacement: a simple and versatile route to hollow nanostructures with tunable and well-controlled properties. Adv. Mater. 25, 6313–6333 (2013).

   CAS Article PubMed PubMed Central Google Scholar

9. 9

   Chou, N. H. & Schaak, R. E. Shape-controlled conversion of beta-Sn nanocrystals into intermetallic M-Sn (M=Fe, Co, Ni, Pd) nanocrystals. J. Am. Chem. Soc. 129, 7339–7345 (2007).

   CAS Article PubMed Google Scholar

10. 10

    Cobley, C. M., Campbell, D. J. & Xia, Y. N. Tailoring the optical and catalytic properties of gold-silver nanoboxes and nanocages by introducing palladium. Adv. Mater. 20, 748–752 (2008).

    CAS Article PubMed PubMed Central Google Scholar

11. 11

    Chen, J. Y. et al. Immuno gold nanocages with tailored optical properties for targeted photothermal destruction of cancer cells. Nano Lett. 7, 1318–1322 (2007).

    CAS Article ADS PubMed PubMed Central Google Scholar

12. 12

    Cang, H. et al. Gold nanocages as contrast agents for spectroscopic optical coherence tomography. Opt. Lett. 30, 3048–3050 (2005).

    CAS Article ADS PubMed Google Scholar

13. 13

    Yang, X. M., Skrabalak, S. E., Li, Z. Y., Xia, Y. N. & Wang, L. H. V. Photoacoustic tomography of a rat cerebral cortex in vivo with au nanocages as an optical contrast agent. Nano Lett. 7, 3798–3802 (2007).

    CAS Article ADS PubMed Google Scholar

14. 14

    Wang, Y. W. et al. Photoacoustic tomography of a nanoshell contrast agent in the in vivo rat brain. Nano Lett. 4, 1689–1692 (2004).

    CAS Article ADS Google Scholar

15. 15

    Heck, K. N., Janesko, B. G., Scuseria, G. E., Halas, N. J. & Wong, M. S. Using catalytic and surface-enhanced Raman spectroscopy-active gold nanoshells to understand the role of basicity in glycerol oxidation. ACS Catal. 3, 2430–2435 (2013).

    CAS Article Google Scholar

16. 16

    Abdollahi, S. N., Naderi, M. & Amoabediny, G. Synthesis and characterization of hollow gold nanoparticles using silica spheres as templates. Colloid Surf. A 436, 1069–1075 (2013).

    CAS Article Google Scholar

17. 17

    Wu, H. X., Wang, P., He, H. L. & Jin, Y. D. Controlled synthesis of porous Ag/Au bimetallic hollow nanoshells with tunable plasmonic and catalytic properties. Nano Res. 5, 135–144 (2012).

    CAS Article ADS Google Scholar

18. 18

    Kim, M. R., Kim, J. Y., Kim, S. J. & Jang, D. J. Laser-induced fabrication of platinum nanoshells having enhanced catalytic and Raman properties. Appl. Catal. A Gen. 393, 317–322 (2011).

    CAS Article Google Scholar

19. 19

    Lee, C. L., Tseng, C. M., Wu, R. B., Wu, C. C. & Syu, S. C. Catalytic characterization of hollow silver/palladium nanoparticles synthesized by a displacement reaction. Electrochim. Acta 54, 5544–5547 (2009).

    CAS Article Google Scholar

20. 20

    Banerjee, I. A. & Regan, M. Biomineralization of porous germania/metal nanoshells for catalysis. Abstr. Pap. Am. Chem. Soc. 229, U677–U677 (2005).

    Google Scholar

21. 21

    Nie, G. D. et al. Sacrificial template-assisted fabrication of palladium hollow nanocubes and their application in electrochemical detection toward hydrogen peroxide. Electrochim. Acta 99, 145–151 (2013).

    CAS Article Google Scholar

22. 22

    Arroyo-Ramirez, L., Rodriguez, D., Otano, W. & Cabrera, C. R. Palladium nanoshell catalysts synthesis on highly ordered pyrolytic graphite for oxygen reduction reaction. ACS Appl. Mater. Interfaces 4, 2018–2024 (2012).

    CAS Article PubMed Google Scholar

23. 23

    Brankovic, S. R., Wang, J. X. & Adzic, R. R. Metal monolayer deposition by replacement of metal adlayers on electrode surfaces. Surf. Sci. 474, L173–L179 (2001).

    CAS Article ADS Google Scholar

24. 24

    Mintsouli, I. et al. Pt-Cu electrocatalysts for methanol oxidation prepared by partial galvanic replacement of Cu/carbon powder precursors. Appl. Catal. B Environ. 136, 160–167 (2013).

    Article Google Scholar

25. 25

    Mintsouli, I. et al. Pt-Ni carbon-supported catalysts for methanol oxidation prepared by Ni electroless deposition and its galvanic replacement by Pt. J. Solid. State Electrochem. 17, 435–443 (2013).

    CAS Article Google Scholar

26. 26

    Mrozek, M. F., Xie, Y. & Weaver, M. J. Surface-enhanced Raman scattering on uniform platinum-group overlayers: Preparation by redox replacement of underpotential-deposited metals on gold. Anal. Chem. 73, 5953–5960 (2001).

    CAS Article PubMed Google Scholar

27. 27

    Papadimitriou, S., Tegou, A., Pavlidou, E., Kokkinidis, G. & Sotiropoulos, S. Methanol oxidation at platinized lead coatings prepared by a two-step electrodeposition-electroless deposition process on glassy carbon and platinum substrates. Electrochim. Acta 52, 6254–6260 (2007).

    CAS Article Google Scholar

28. 28

    Shao, M. H. et al. Palladium monolayer and palladium alloy electrocatalysts for oxygen reduction. Langmuir 22, 10409–10415 (2006).

    CAS Article PubMed Google Scholar

29. 29

    Tegou, A. et al. Oxygen reduction at platinum- and gold-coated iron, cobalt, nickel and lead deposits on glassy carbon substrates. J. Electroanal. Chem. 623, 187–196 (2008).

    CAS Article Google Scholar

30. 30

    Tegou, A., Papadimitriou, S., Kokkinidis, G. & Sotiropoulos, S. A rotating disc electrode study of oxygen reduction at platinised nickel and cobalt coatings. J. Solid. State Electrochem. 14, 175–184 (2010).

    CAS Article Google Scholar

31. 31

    Tegou, A., Papadimitriou, S., Pavfidou, E., Kokkinidis, G. & Sotiropouios, S. Oxygen reduction at platinum- and gold-coated copper deposits on glassy carbon substrates. J. Electroanal. Chem. 608, 67–77 (2007).

    CAS Article Google Scholar

32. 32

    Van Brussel, M., Kokkinidis, G., Hubin, A. & Buess-Herman, C. Oxygen reduction at platinum modified gold electrodes. Electrochim. Acta 48, 3909–3919 (2003).

    CAS Article Google Scholar

33. 33

    Van Brussel, M., Kokkinidis, G., Vandendael, I. & Buess-Herman, C. High performance gold-supported platinum electrocatalyst for oxygen reduction. Electrochem. Commun. 4, 808–813 (2002).

    CAS Article Google Scholar

34. 34

    Xia, Y. N. et al. Gold nanocages: from synthesis to theranostic applications. Acc. Chem. Res. 44, 914–924 (2011).

    CAS Article PubMed PubMed Central Google Scholar

35. 35

    Sun, Y. G. & Wang, Y. X. Monitoring of galvanic replacement reaction between silver nanowires and HAuCl4 by in situ transmission X-ray microscopy. Nano Lett. 11, 4386–4392 (2011).

    CAS Article ADS PubMed Google Scholar

36. 36

    Zheng, H. M. et al. Observation of single colloidal platinum nanocrystal growth trajectories. Science 324, 1309–1312 (2009).

    CAS Article ADS PubMed Google Scholar

37. 37

    Evans, J. E., Jungjohann, K. L., Browning, N. D. & Arslan, I. Controlled growth of nanoparticles from solution with in situ liquid transmission electron microscopy. Nano Lett. 11, 2809–2813 (2011).

    CAS Article ADS PubMed PubMed Central Google Scholar

38. 38

    Parent, L. R. et al. Direct in situ observation of nanoparticle synthesis in a liquid crystal surfactant template. ACS Nano 6, 3589–3596 (2012).

    CAS Article PubMed Google Scholar

39. 39

    Jungjohann, K. L., Bliznakov, S., Sutter, P. W., Stach, E. A. & Sutter, E. A. In situ liquid cell electron microscopy of the solution growth of Au–Pd core-shell nanostructures. Nano Lett. 13, 2964–2970 (2013).

    CAS Article ADS PubMed Google Scholar

40. 40

    Williamson, M. J., Tromp, R. M., Vereecken, P. M., Hull, R. & Ross, F. M. Dynamic microscopy of nanoscale cluster growth at the solid-liquid interface. Nat. Mater. 2, 532–536 (2003).

    CAS Article ADS PubMed Google Scholar

41. 41

    White, E. R. et al. In situ transmission electron microscopy of lead dendrites and lead ions in aqueous solution. ACS Nano 6, 6308–6317 (2012).

    CAS Article PubMed PubMed Central Google Scholar

42. 42

    Chen, X., Noh, K. W., Wen, J. G. & Dillon, S. J. In situ electrochemical wet cell transmission electron microscopy characterization of solid-liquid interactions between Ni and aqueous NiCl2 . Acta Mater. 60, 192–198 (2012).

    CAS Article Google Scholar

43. 43

    Jungjohann, K. L., Evans, J. E., Aguiar, J. A., Arslan, I. & Browning, N. D. Atomic-scale imaging and spectroscopy for in situ liquid scanning transmission electron microscopy. Microsc. Microanal. 18, 621–627 (2012).

    CAS Article ADS PubMed Google Scholar

44. 44

    Li, D. S. et al. Direction-specific interactions control crystal growth by oriented attachment. Science 336, 1014–1018 (2012).

    CAS Article ADS PubMed Google Scholar

45. 45

    Woehl, T. J., Evans, J. E., Arslan, L., Ristenpart, W. D. & Browning, N. D. Direct in situ determination of the mechanisms controlling nanoparticle nucleation and growth. ACS Nano 6, 8599–8610 (2012).

    CAS Article PubMed PubMed Central Google Scholar

46. 46

    Abellan, P. et al. Factors influencing quantitative liquid (scanning) transmission electron microscopy. Chem. Commun. 50, 4873–4880 (2014).

    CAS Article Google Scholar

47. 47

    Woehl, T. J. et al. Direct observation of aggregative nanoparticle growth: kinetic modeling of the size distribution and growth rate. Nano Lett. 14, 373–378 (2013).

    Article ADS PubMed Google Scholar

48. 48

    Liao, H. G., Cui, L. K., Whitelam, S. & Zheng, H. M. Real-time imaging of Pt3Fe nanorod growth in solution. Science 336, 1011–1014 (2012).

    CAS Article ADS PubMed Google Scholar

49. 49

    Zheng, H. M., Claridge, S. A., Minor, A. M., Alivisatos, A. P. & Dahmen, U. Nanocrystal diffusion in a liquid thin film observed by in situ transmission electron microscopy. Nano Lett. 9, 2460–2465 (2009).

    CAS Article ADS PubMed Google Scholar

50. 50

    Ptacek, P. & Bastl, Z. Xps characterization of supported bimetallic palladium silver clusters. Appl. Surf. Sci. 45, 319–323 (1990).

    CAS Article ADS Google Scholar

51. 51

    Mariot, J. M., Hague, C. F. & Dufour, G. Deviations from one-electron behavior in the Ag and Pd M4,5-Vv auger-spectra of Agcpd1-C Alloys. Phys. Rev. B 23, 3164–3170 (1981).

    CAS Article ADS Google Scholar

52. 52

    Weightman, P. & Andrews, P. T. The Pd M4,5n4,5n4,5 auger-spectra of Agpd alloys. J. Phys. C Solid State 13, L821–L825 (1980).

    CAS Article ADS Google Scholar

53. 53

    Chen, J. Y. et al. Optical properties of Pd-Ag and Pt-Ag nanoboxes synthesized via galvanic replacement reactions. Nano Lett. 5, 2058–2062 (2005).

    CAS Article ADS PubMed Google Scholar

54. 54

    White, E. R., Mecklenburg, M., Shevitski, B., Singer, S. B. & Regan, B. C. Charged nanoparticle dynamics in water induced by scanning transmission electron microscopy. Langmuir 28, 3695–3698 (2012).

    CAS Article PubMed PubMed Central Google Scholar

55. 55

    Buxton, G. V. & Sellers, R. M. Radiation-chemistry of metal-ions in aqueous-solution. Coordin. Chem. Rev. 22, 195–274 (1977).

    CAS Article Google Scholar

56. 56

    Buxton, G. V., Greenstock, C. L., Helman, W. P. & Ross, A. B. Critical-review of rate constants for reactions of hydrated electrons, hydrogen-atoms and hydroxyl radicals (.Oh/.O-) in aqueous-solution. J. Phys. Chem. Ref. Data 17, 513–886 (1988).

    CAS Article ADS Google Scholar

57. 57

    Michaelis, M. & Henglein, A. Reduction of Pd(II) in aqueous-solution - stabilization and reactions of an intermediate cluster and Pd colloid formation. J. Phys. Chem. 96, 4719–4724 (1992).

    CAS Article Google Scholar

58. 58

    Belloni, J., Mostafavi, M., Remita, H., Marignier, J. L. & Delcourt, M. O. Radiation-induced synthesis of mono- and multi-metallic clusters and nanocolloids. New J. Chem. 22, 1239–1255 (1998).

    CAS Article Google Scholar

59. 59

    Alam, M. S. et al. Concomitant transient electrochemical and spectroscopic detection with electron pulse radiolysis. Electrochem. Commun. 35, 149–151 (2013).

    CAS Article Google Scholar

60. 60

    Siefermann, K. R. et al. Binding energies, lifetimes and implications of bulk and interface solvated electrons in water. Nat. Chem. 2, 274–279 (2010).

    CAS Article PubMed Google Scholar

61. 61

    Roots, R. & Okada, S. Estimation of life times and diffusion distances of radicals involved in X-Ray-induced DNA strand breaks or killing of mammalian cells. Radiat. Res. 64, 306–320 (1975).

    CAS Article ADS PubMed Google Scholar

62. 62

    Turchi, C. & Ollis, D. Photocatalytic degradation of organic water contaminants: mechanisms involving hydroxyl radical attack. J. Catal. 122, 178–192 (1990).

    CAS Article Google Scholar

63. 63

    Boag, J. W. & Hart, E. J. Absorption spectra in irradiated water and some solutions—absorption spectra of hydrated electron. Nature 197, 45–46 (1963).

    CAS Article ADS Google Scholar

Download references

## Acknowledgements

This research has been carried out at the Center for Functional Nanomaterials, the Brookhaven National Laboratory, which is supported by the US Department of Energy, the Office of Basic Energy Sciences, under Contract No. DE-AC02–98CH10886. This work was supported in part (AC and EM) by the LabEx MiChem part of French state funds managed by the ANR within the Investissements d'Avenir programme under reference ANR-11-IDEX-0004-02.

## Author information

### Affiliations

1. Center for Functional Nanomaterials, Brookhaven National Laboratory, Upton, 11973, New York, USA

   E. Sutter, K. Jungjohann, S. Tenney & P. Sutter

2. Department of Chemistry, Brookhaven National Laboratory, Upton, 11973, New York, USA

   S. Bliznakov

3. Sorbonne Universités, UPMC Univ Paris 06, UMR 8233, CNRS, Laboratoire Monaris, Paris, F-75005, France

   A. Courty

4. Sorbonne Universités, UPMC Univ Paris 06, UMR 8235, Laboratoire Interfaces et Systèmes Electrochimiques, Paris, F-75005, France

   E. Maisonhaute

Authors

1. E. Sutter
   View author publications

   You can also search for this author in PubMed Google Scholar

2. K. Jungjohann
   View author publications

   You can also search for this author in PubMed Google Scholar

3. S. Bliznakov
   View author publications

   You can also search for this author in PubMed Google Scholar

4. A. Courty
   View author publications

   You can also search for this author in PubMed Google Scholar

5. E. Maisonhaute
   View author publications

   You can also search for this author in PubMed Google Scholar

6. S. Tenney
   View author publications

   You can also search for this author in PubMed Google Scholar

7. P. Sutter
   View author publications

   You can also search for this author in PubMed Google Scholar

### Contributions

E.S. and P.S. designed and planned the experiments, and wrote the manuscript. E.S. and K.J. performed the in situ TEM/STEM experiments. E.S., K.J. and P.S. analyzed the results. S.B. performed ex situ electrochemical characterization of the nanostructures and participated in discussions of the results. S.T. performed the XPS and ISS characterization. A.C. and E.M. participated in planning the experiments and discussing the results. E.S. coordinated the research. All authors read and commented on the manuscript.

### Corresponding author

Correspondence to E. Sutter.

## Ethics declarations

### Competing interests

The authors declare no competing financial interests.

## Supplementary information

Supplementary Figures 1-4 (PDF 476 kb)

### Supplementary Movie 1

Sequence TEM images following Au nanoparticles in 50 μM aqueous PdCl2 solution over 52 s (Electron dose rate: 15.6 e- ·Å ·s-1, electron dose per image: 5.2 e- ·Å-2). (AVI 7352 kb)

### Supplementary Movie 2

Selected DF-STEM images of Ag-Pd nanocages taken at different tilt angles between -15° and 15°. (AVI 666 kb)

### Supplementary Movie 3

Sequence of dark field STEM images following Ag nanoparticles in 50 μM aqueous PdCl2 solution over 109 s (Electron dose rate: 3.18 e- ·Å2 ·s-1, frame time: 8.4 s, electron dose per image: 26.2 e- ·Å-2). FOV: 1864 nm × 1864 nm (AVI 3591 kb)

### Supplementary Movie 4

Sequence of dark field STEM images following Ag nanoparticles in 50 μM aqueous PdCl2 solution over 59 s (Electron dose rate: 6.26 e- ·Å2 ·s-1, frame time: 8.4 s, electron dose per image: 52 e- ·Å-2). FOV: 1328 nm × 1328 nm (AVI 1222 kb)

## Rights and permissions

Reprints and Permissions

## About this article

### Cite this article

Sutter, E., Jungjohann, K., Bliznakov, S. et al. In situ liquid-cell electron microscopy of silver–palladium galvanic replacement reactions on silver nanoparticles. Nat Commun 5, 4946 (2014). https://doi.org/10.1038/ncomms5946

Download citation

- Received: 19 April 2014

- Accepted: 10 August 2014

- Published: 11 September 2014

- DOI: https://doi.org/10.1038/ncomms5946

## Further reading

- ### Nanofabrication of hollowed-out Au@AgPt core-frames via selective carving of silver and deposition of platinum

  - Chang Xia
  - , Wei He
  - , Peng Fei Gao
  - , Jia Ru Wang
  - , Zheng Mao Cao
  - , Yuan Fang Li
  - , Yi Wang
  - & Cheng Zhi Huang

  Chemical Communications (2020)

- ### Imaging the kinetics of anisotropic dissolution of bimetallic core–shell nanocubes using graphene liquid cells

  - Lei Chen
  - , Alberto Leonardi
  - , Jun Chen
  - , Muhan Cao
  - , Na Li
  - , Dong Su
  - , Qiao Zhang
  - , Michael Engel
  - & Xingchen Ye

  Nature Communications (2020)

- ### Liquid phase transmission electron microscopy for imaging of nanoscale processes in solution

  - Utkur Mirsaidov
  - , Joseph P. Patterson
  - & Haimei Zheng

  MRS Bulletin (2020)

- ### Electron-beam-driven chemical processes during liquid phase transmission electron microscopy

  - Taylor J. Woehl
  - , Trevor Moser
  - , James E. Evans
  - & Frances M. Ross

  MRS Bulletin (2020)

- ### Nucleation, growth, and superlattice formation of nanocrystals observed in liquid cell transmission electron microscopy

  - Qian Chen
  - , Jong Min Yuk
  - , Matthew R. Hauwiller
  - , Jungjae Park
  - , Kyun Seong Dae
  - , Jae Sung Kim
  - & A. Paul Alivisatos

  MRS Bulletin (2020)

## Comments

By submitting a comment you agree to abide by our Terms and Community Guidelines. If you find something abusive or that does not comply with our terms or guidelines please flag it as inappropriate.

Download PDF

Sign up for the Nature Briefing newsletter — what matters in science, free to your inbox daily.

Email address
I agree my information will be processed in accordance with the Nature and Springer Nature Limited Privacy Policy.
Get the most important science stories of the day, free in your inbox. Sign up for Nature Briefing